@@ -65,9 +65,10 @@ Usage example:
 [I 13-02-19 10:56:27] 127.0.0.1:34179-[user] RETR /home/giampaolo/.vimrc
                       completed=1 bytes=1700 seconds=0.001
 [I 13-02-19 10:56:39] 127.0.0.1:34179-[user] FTP session closed (disconnect).
+
 """
 
 
-__ver__ = '1.5.9'
+__ver__ = "2.1.0"
 __author__ = "Giampaolo Rodola' <g.rodola@gmail.com>"
-__web__ = 'https://github.com/giampaolo/pyftpdlib/'
+__web__ = "https://github.com/giampaolo/pyftpdlib/"
