@@ -1,61 +1,45 @@
-#!/usr/bin/env python
-
-#  ======================================================================
-#  Copyright (C) 2007-2014 Giampaolo Rodola' <g.rodola@gmail.com>
-#
-#                         All Rights Reserved
-#
-# Permission is hereby granted, free of charge, to any person
-# obtaining a copy of this software and associated documentation
-# files (the "Software"), to deal in the Software without
-# restriction, including without limitation the rights to use,
-# copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the
-# Software is furnished to do so, subject to the following
-# conditions:
-#
-# The above copyright notice and this permission notice shall be
-# included in all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
-# OTHER DEALINGS IN THE SOFTWARE.
-#
-#  ======================================================================
+# Copyright (C) 2007 Giampaolo Rodola' <g.rodola@gmail.com>.
+# Use of this source code is governed by MIT license that can be
+# found in the LICENSE file.
 
 import os
-import time
-import tempfile
 import stat
+import tempfile
+import time
+
+from .utils import memoize
+
 try:
-    from stat import filemode as _filemode  # PY 3.3
-except ImportError:
-    from tarfile import filemode as _filemode
-try:
-    import pwd
     import grp
+    import pwd
 except ImportError:
     pwd = grp = None
 
-from pyftpdlib._compat import PY3, u, unicode, property
+
+__all__ = ["AbstractedFS", "FilesystemError"]
 
 
-__all__ = ['FilesystemError', 'AbstractedFS']
-
-
-_months_map = {1: 'Jan', 2: 'Feb', 3: 'Mar', 4: 'Apr', 5: 'May', 6: 'Jun',
-               7: 'Jul', 8: 'Aug', 9: 'Sep', 10: 'Oct', 11: 'Nov', 12: 'Dec'}
+_months_map = {
+    1: "Jan",
+    2: "Feb",
+    3: "Mar",
+    4: "Apr",
+    5: "May",
+    6: "Jun",
+    7: "Jul",
+    8: "Aug",
+    9: "Sep",
+    10: "Oct",
+    11: "Nov",
+    12: "Dec",
+}
 
 
 # ===================================================================
 # --- custom exceptions
 # ===================================================================
 
+
 class FilesystemError(Exception):
     """Custom class for filesystem-related exceptions.
     You can raise this from an AbstractedFS subclass in order to
@@ -67,7 +51,8 @@ class FilesystemError(Exception):
 # --- base class
 # ===================================================================
 
-class AbstractedFS(object):
+
+class AbstractedFS:
     """A class used to interact with the file system, providing a
     cross-platform interface compatible with both Windows and
     UNIX style filesystems where all paths use "/" separator.
@@ -88,16 +73,15 @@ class AbstractedFS(object):
 
     def __init__(self, root, cmd_channel):
         """
-         - (str) root: the user "real" home directory (e.g. '/home/user')
-         - (instance) cmd_channel: the FTPHandler class instance
+        - (str) root: the user "real" home directory (e.g. '/home/user')
+        - (instance) cmd_channel: the FTPHandler class instance.
         """
-        assert isinstance(root, unicode)
         # Set initial current working directory.
         # By default initial cwd is set to "/" to emulate a chroot jail.
         # If a different behavior is desired (e.g. initial cwd = root,
         # to reflect the real filesystem) users overriding this class
         # are responsible to set _cwd attribute as necessary.
-        self._cwd = u('/')
+        self._cwd = "/"
         self._root = root
         self.cmd_channel = cmd_channel
 
@@ -113,16 +97,24 @@ class AbstractedFS(object):
 
     @root.setter
     def root(self, path):
-        assert isinstance(path, unicode), path
         self._root = path
 
     @cwd.setter
     def cwd(self, path):
-        assert isinstance(path, unicode), path
         self._cwd = path
 
     # --- Pathname / conversion utilities
 
+    @staticmethod
+    def _isabs(path, _windows=os.name == "nt"):
+        # Windows + Python 3.13: isabs() changed so that a path
+        # starting with "/" is no longer considered absolute.
+        # https://github.com/python/cpython/issues/44626
+        # https://github.com/python/cpython/pull/113829/
+        if _windows and path.startswith("/"):
+            return True
+        return os.path.isabs(path)
+
     def ftpnorm(self, ftppath):
         """Normalize a "virtual" ftp pathname (typically the raw string
         coming from client) depending on the current working directory.
@@ -134,8 +126,7 @@ class AbstractedFS(object):
         Note: directory separators are system independent ("/").
         Pathname returned is always absolutized.
         """
-        assert isinstance(ftppath, unicode), ftppath
-        if os.path.isabs(ftppath):
+        if self._isabs(ftppath):
             p = os.path.normpath(ftppath)
         else:
             p = os.path.normpath(os.path.join(self.cwd, ftppath))
@@ -146,13 +137,13 @@ class AbstractedFS(object):
         # os.path.normpath supports UNC paths (e.g. "//a/b/c") but we
         # don't need them.  In case we get an UNC path we collapse
         # redundant separators appearing at the beginning of the string
-        while p[:2] == '//':
+        while p[:2] == "//":
             p = p[1:]
         # Anti path traversal: don't trust user input, in the event
         # that self.cwd is not absolute, return "/" as a safety measure.
         # This is for extra protection, maybe not really necessary.
-        if not os.path.isabs(p):
-            p = u("/")
+        if not self._isabs(p):
+            p = "/"
         return p
 
     def ftp2fs(self, ftppath):
@@ -166,7 +157,6 @@ class AbstractedFS(object):
 
         Note: directory separators are system dependent.
         """
-        assert isinstance(ftppath, unicode), ftppath
         # as far as I know, it should always be path traversal safe...
         if os.path.normpath(self.root) == os.sep:
             return os.path.normpath(self.ftpnorm(ftppath))
@@ -189,17 +179,16 @@ class AbstractedFS(object):
         On invalid pathnames escaping from user's root directory
         (e.g. "/home" when root is "/home/user") always return "/".
         """
-        assert isinstance(fspath, unicode), fspath
-        if os.path.isabs(fspath):
+        if self._isabs(fspath):
             p = os.path.normpath(fspath)
         else:
             p = os.path.normpath(os.path.join(self.root, fspath))
         if not self.validpath(p):
-            return u('/')
+            return "/"
         p = p.replace(os.sep, "/")
-        p = p[len(self.root):]
-        if not p.startswith('/'):
-            p = '/' + p
+        p = p[len(self.root) :]
+        if not p.startswith("/"):
+            p = "/" + p
         return p
 
     def validpath(self, path):
@@ -212,30 +201,28 @@ class AbstractedFS(object):
         Pathnames escaping from user's root directory are considered
         not valid.
         """
-        assert isinstance(path, unicode), path
         root = self.realpath(self.root)
         path = self.realpath(path)
         if not root.endswith(os.sep):
-            root = root + os.sep
+            root += os.sep
         if not path.endswith(os.sep):
-            path = path + os.sep
-        if path[0:len(root)] == root:
-            return True
-        return False
+            path += os.sep
+        return path[0 : len(root)] == root
 
     # --- Wrapper methods around open() and tempfile.mkstemp
 
     def open(self, filename, mode):
         """Open a file returning its handler."""
-        assert isinstance(filename, unicode), filename
         return open(filename, mode)
 
-    def mkstemp(self, suffix='', prefix='', dir=None, mode='wb'):
+    def mkstemp(self, suffix="", prefix="", dir=None, mode="wb"):
         """A wrap around tempfile.mkstemp creating a file with a unique
         name.  Unlike mkstemp it returns an object with a file-like
         interface.
         """
+
         class FileWrapper:
+
             def __init__(self, fd, name):
                 self.file = fd
                 self.name = name
@@ -243,7 +230,7 @@ class AbstractedFS(object):
             def __getattr__(self, attr):
                 return getattr(self.file, attr)
 
-        text = 'b' not in mode
+        text = "b" not in mode
         # max number of tries to find out a unique file name
         tempfile.TMP_MAX = 50
         fd, name = tempfile.mkstemp(suffix, prefix, dir, text=text)
@@ -253,94 +240,91 @@ class AbstractedFS(object):
     # --- Wrapper methods around os.* calls
 
     def chdir(self, path):
-        """Change the current directory."""
+        """Change the current directory. If this method is overridden
+        it is vital that `cwd` attribute gets set.
+        """
         # note: process cwd will be reset by the caller
-        assert isinstance(path, unicode), path
         os.chdir(path)
-        self._cwd = self.fs2ftp(path)
+        self.cwd = self.fs2ftp(path)
 
     def mkdir(self, path):
         """Create the specified directory."""
-        assert isinstance(path, unicode), path
         os.mkdir(path)
 
     def listdir(self, path):
         """List the content of a directory."""
-        assert isinstance(path, unicode), path
+        return os.listdir(path)
+
+    def listdirinfo(self, path):
+        """List the content of a directory."""
         return os.listdir(path)
 
     def rmdir(self, path):
         """Remove the specified directory."""
-        assert isinstance(path, unicode), path
         os.rmdir(path)
 
     def remove(self, path):
         """Remove the specified file."""
-        assert isinstance(path, unicode), path
         os.remove(path)
 
     def rename(self, src, dst):
         """Rename the specified src file to the dst filename."""
-        assert isinstance(src, unicode), src
-        assert isinstance(dst, unicode), dst
         os.rename(src, dst)
 
     def chmod(self, path, mode):
         """Change file/directory mode."""
-        assert isinstance(path, unicode), path
-        if not hasattr(os, 'chmod'):
+        if not hasattr(os, "chmod"):
             raise NotImplementedError
         os.chmod(path, mode)
 
     def stat(self, path):
         """Perform a stat() system call on the given path."""
-        # on python 2 we might also get bytes from os.lisdir()
-        # assert isinstance(path, unicode), path
         return os.stat(path)
 
-    if hasattr(os, 'lstat'):
+    def utime(self, path, timeval):
+        """Perform a utime() call on the given path."""
+        # utime expects a int/float (atime, mtime) in seconds
+        # thus, setting both access and modify time to timeval
+        return os.utime(path, (timeval, timeval))
+
+    if hasattr(os, "lstat"):
+
         def lstat(self, path):
             """Like stat but does not follow symbolic links."""
-            # on python 2 we might also get bytes from os.lisdir()
-            # assert isinstance(path, unicode), path
             return os.lstat(path)
+
     else:
         lstat = stat
 
-    if hasattr(os, 'readlink'):
+    if hasattr(os, "readlink"):
+
         def readlink(self, path):
             """Return a string representing the path to which a
             symbolic link points.
             """
-            assert isinstance(path, unicode), path
             return os.readlink(path)
 
     # --- Wrapper methods around os.path.* calls
 
     def isfile(self, path):
         """Return True if path is a file."""
-        assert isinstance(path, unicode), path
         return os.path.isfile(path)
 
     def islink(self, path):
         """Return True if path is a symbolic link."""
-        assert isinstance(path, unicode), path
         return os.path.islink(path)
 
     def isdir(self, path):
         """Return True if path is a directory."""
-        assert isinstance(path, unicode), path
         return os.path.isdir(path)
 
     def getsize(self, path):
         """Return the size of the specified file in bytes."""
-        assert isinstance(path, unicode), path
         return os.path.getsize(path)
 
     def getmtime(self, path):
         """Return the last modified time as a number of seconds since
         the epoch."""
-        assert isinstance(path, unicode), path
         return os.path.getmtime(path)
 
     def realpath(self, path):
@@ -348,17 +332,16 @@ class AbstractedFS(object):
         symbolic links encountered in the path (if they are
         supported by the operating system).
         """
-        assert isinstance(path, unicode), path
         return os.path.realpath(path)
 
     def lexists(self, path):
         """Return True if path refers to an existing path, including
         a broken or circular symbolic link.
         """
-        assert isinstance(path, unicode), path
         return os.path.lexists(path)
 
     if pwd is not None:
+
         def get_user_by_uid(self, uid):
             """Return the username associated with user id.
             If this can't be determined return raw uid instead.
@@ -368,13 +351,16 @@ class AbstractedFS(object):
                 return pwd.getpwuid(uid).pw_name
             except KeyError:
                 return uid
+
     else:
+
         def get_user_by_uid(self, uid):
             return "owner"
 
     if grp is not None:
+
         def get_group_by_gid(self, gid):
-            """Return the groupname associated with group id.
+            """Return the group name associated with group id.
             If this can't be determined return raw gid instead.
             On Windows just return "group".
             """
@@ -382,35 +368,14 @@ class AbstractedFS(object):
                 return grp.getgrgid(gid).gr_name
             except KeyError:
                 return gid
+
     else:
+
         def get_group_by_gid(self, gid):
             return "group"
 
     # --- Listing utilities
 
-    def get_list_dir(self, path):
-        """"Return an iterator object that yields a directory listing
-        in a form suitable for LIST command.
-        """
-        assert isinstance(path, unicode), path
-        if self.isdir(path):
-            listing = self.listdir(path)
-            try:
-                listing.sort()
-            except UnicodeDecodeError:
-                # (Python 2 only) might happen on filesystem not
-                # supporting UTF8 meaning os.listdir() returned a list
-                # of mixed bytes and unicode strings:
-                # http://goo.gl/6DLHD
-                # http://bugs.python.org/issue683592
-                pass
-            return self.format_list(path, listing)
-        # if path is a file or a symlink we return information about it
-        else:
-            basedir, filename = os.path.split(path)
-            self.lstat(path)  # raise exc in case of problems
-            return self.format_list(basedir, [filename])
-
     def format_list(self, basedir, listing, ignore_err=True):
         """Return an iterator object that yields the entries of given
         directory emulating the "/bin/ls -lA" UNIX command output.
@@ -432,31 +397,24 @@ class AbstractedFS(object):
         drwxrwxrwx   1 owner   group          0 Aug 31 18:50 e-books
         -rw-rw-rw-   1 owner   group        380 Sep 02  3:40 module.py
         """
-        assert isinstance(basedir, unicode), basedir
-        if listing:
-            assert isinstance(listing[0], unicode)
+
+        @memoize
+        def get_user_by_uid(uid):
+            return self.get_user_by_uid(uid)
+
+        @memoize
+        def get_group_by_gid(gid):
+            return self.get_group_by_gid(gid)
+
         if self.cmd_channel.use_gmt_times:
             timefunc = time.gmtime
         else:
             timefunc = time.localtime
         SIX_MONTHS = 180 * 24 * 60 * 60
-        readlink = getattr(self, 'readlink', None)
+        readlink = getattr(self, "readlink", None)
         now = time.time()
         for basename in listing:
-            if not PY3:
-                try:
-                    file = os.path.join(basedir, basename)
-                except UnicodeDecodeError:
-                    # (Python 2 only) might happen on filesystem not
-                    # supporting UTF8 meaning os.listdir() returned a list
-                    # of mixed bytes and unicode strings:
-                    # http://goo.gl/6DLHD
-                    # http://bugs.python.org/issue683592
-                    file = os.path.join(bytes(basedir), bytes(basename))
-                    if not isinstance(basename, unicode):
-                        basename = unicode(basename, 'utf8', 'ignore')
-            else:
-                file = os.path.join(basedir, basename)
+            file = os.path.join(basedir, basename)
             try:
                 st = self.lstat(file)
             except (OSError, FilesystemError):
@@ -464,31 +422,32 @@ class AbstractedFS(object):
                     continue
                 raise
 
-            perms = _filemode(st.st_mode)  # permissions
+            perms = stat.filemode(st.st_mode)  # permissions
             nlinks = st.st_nlink  # number of links to inode
             if not nlinks:  # non-posix system, let's use a bogus value
                 nlinks = 1
             size = st.st_size  # file size
-            uname = self.get_user_by_uid(st.st_uid)
-            gname = self.get_group_by_gid(st.st_gid)
+            uname = get_user_by_uid(st.st_uid)
+            gname = get_group_by_gid(st.st_gid)
             mtime = timefunc(st.st_mtime)
             # if modification time > 6 months shows "month year"
             # else "month hh:mm";  this matches proftpd format, see:
             # https://github.com/giampaolo/pyftpdlib/issues/187
-            if (now - st.st_mtime) > SIX_MONTHS:
-                fmtstr = "%d  %Y"
-            else:
-                fmtstr = "%d %H:%M"
+            fmtstr = "%d  %Y" if now - st.st_mtime > SIX_MONTHS else "%d %H:%M"
             try:
-                mtimestr = "%s %s" % (_months_map[mtime.tm_mon],
-                                      time.strftime(fmtstr, mtime))
+                mtimestr = "%s %s" % (
+                    _months_map[mtime.tm_mon],
+                    time.strftime(fmtstr, mtime),
+                )
             except ValueError:
                 # It could be raised if last mtime happens to be too
                 # old (prior to year 1900) in which case we return
                 # the current time as last mtime.
                 mtime = timefunc()
-                mtimestr = "%s %s" % (_months_map[mtime.tm_mon],
-                                      time.strftime("%d %H:%M", mtime))
+                mtimestr = "%s %s" % (
+                    _months_map[mtime.tm_mon],
+                    time.strftime("%d %H:%M", mtime),
+                )
 
             # same as stat.S_ISLNK(st.st_mode) but slighlty faster
             islink = (st.st_mode & 61440) == stat.S_IFLNK
@@ -503,8 +462,17 @@ class AbstractedFS(object):
 
             # formatting is matched with proftpd ls output
             line = "%s %3s %-8s %-8s %8s %s %s\r\n" % (
-                perms, nlinks, uname, gname, size, mtimestr, basename)
-            yield line.encode('utf8', self.cmd_channel.unicode_errors)
+                perms,
+                nlinks,
+                uname,
+                gname,
+                size,
+                mtimestr,
+                basename,
+            )
+            yield line.encode(
+                self.cmd_channel.encoding, self.cmd_channel.unicode_errors
+            )
 
     def format_mlsx(self, basedir, listing, perms, facts, ignore_err=True):
         """Return an iterator object that yields the entries of a given
@@ -532,44 +500,28 @@ class AbstractedFS(object):
         type=dir;size=0;perm=el;modify=20071127230206;unique=801e33; ebooks
         type=file;size=211;perm=r;modify=20071103093626;unique=192; module.py
         """
-        assert isinstance(basedir, unicode), basedir
-        if listing:
-            assert isinstance(listing[0], unicode)
         if self.cmd_channel.use_gmt_times:
             timefunc = time.gmtime
         else:
             timefunc = time.localtime
-        permdir = ''.join([x for x in perms if x not in 'arw'])
-        permfile = ''.join([x for x in perms if x not in 'celmp'])
-        if ('w' in perms) or ('a' in perms) or ('f' in perms):
-            permdir += 'c'
-        if 'd' in perms:
-            permdir += 'p'
-        show_type = 'type' in facts
-        show_perm = 'perm' in facts
-        show_size = 'size' in facts
-        show_modify = 'modify' in facts
-        show_create = 'create' in facts
-        show_mode = 'unix.mode' in facts
-        show_uid = 'unix.uid' in facts
-        show_gid = 'unix.gid' in facts
-        show_unique = 'unique' in facts
+        permdir = "".join([x for x in perms if x not in "arw"])
+        permfile = "".join([x for x in perms if x not in "celmp"])
+        if ("w" in perms) or ("a" in perms) or ("f" in perms):
+            permdir += "c"
+        if "d" in perms:
+            permdir += "p"
+        show_type = "type" in facts
+        show_perm = "perm" in facts
+        show_size = "size" in facts
+        show_modify = "modify" in facts
+        show_create = "create" in facts
+        show_mode = "unix.mode" in facts
+        show_uid = "unix.uid" in facts
+        show_gid = "unix.gid" in facts
+        show_unique = "unique" in facts
         for basename in listing:
-            retfacts = dict()
-            if not PY3:
-                try:
-                    file = os.path.join(basedir, basename)
-                except UnicodeDecodeError:
-                    # (Python 2 only) might happen on filesystem not
-                    # supporting UTF8 meaning os.listdir() returned a list
-                    # of mixed bytes and unicode strings:
-                    # http://goo.gl/6DLHD
-                    # http://bugs.python.org/issue683592
-                    file = os.path.join(bytes(basedir), bytes(basename))
-                    if not isinstance(basename, unicode):
-                        basename = unicode(basename, 'utf8', 'ignore')
-            else:
-                file = os.path.join(basedir, basename)
+            retfacts = {}
+            file = os.path.join(basedir, basename)
             # in order to properly implement 'unique' fact (RFC-3659,
             # chapter 7.5.2) we are supposed to follow symlinks, hence
             # use os.stat() instead of os.lstat()
@@ -584,26 +536,27 @@ class AbstractedFS(object):
             isdir = (st.st_mode & 61440) == stat.S_IFDIR
             if isdir:
                 if show_type:
-                    if basename == '.':
-                        retfacts['type'] = 'cdir'
-                    elif basename == '..':
-                        retfacts['type'] = 'pdir'
+                    if basename == ".":
+                        retfacts["type"] = "cdir"
+                    elif basename == "..":
+                        retfacts["type"] = "pdir"
                     else:
-                        retfacts['type'] = 'dir'
+                        retfacts["type"] = "dir"
                 if show_perm:
-                    retfacts['perm'] = permdir
+                    retfacts["perm"] = permdir
             else:
                 if show_type:
-                    retfacts['type'] = 'file'
+                    retfacts["type"] = "file"
                 if show_perm:
-                    retfacts['perm'] = permfile
+                    retfacts["perm"] = permfile
             if show_size:
-                retfacts['size'] = st.st_size  # file size
+                retfacts["size"] = st.st_size  # file size
             # last modification time
             if show_modify:
                 try:
-                    retfacts['modify'] = time.strftime("%Y%m%d%H%M%S",
-                                                       timefunc(st.st_mtime))
+                    retfacts["modify"] = time.strftime(
+                        "%Y%m%d%H%M%S", timefunc(st.st_mtime)
+                    )
                 # it could be raised if last mtime happens to be too old
                 # (prior to year 1900)
                 except ValueError:
@@ -611,17 +564,18 @@ class AbstractedFS(object):
             if show_create:
                 # on Windows we can provide also the creation time
                 try:
-                    retfacts['create'] = time.strftime("%Y%m%d%H%M%S",
-                                                       timefunc(st.st_ctime))
+                    retfacts["create"] = time.strftime(
+                        "%Y%m%d%H%M%S", timefunc(st.st_ctime)
+                    )
                 except ValueError:
                     pass
             # UNIX only
             if show_mode:
-                retfacts['unix.mode'] = oct(st.st_mode & 511)
+                retfacts["unix.mode"] = oct(st.st_mode & 511)
             if show_uid:
-                retfacts['unix.uid'] = st.st_uid
+                retfacts["unix.uid"] = st.st_uid
             if show_gid:
-                retfacts['unix.gid'] = st.st_gid
+                retfacts["unix.gid"] = st.st_gid
 
             # We provide unique fact (see RFC-3659, chapter 7.5.2) on
             # posix platforms only; we get it by mixing st_dev and
@@ -632,21 +586,24 @@ class AbstractedFS(object):
             # platforms should use some platform-specific method (e.g.
             # on Windows NTFS filesystems MTF records could be used).
             if show_unique:
-                retfacts['unique'] = "%xg%x" % (st.st_dev, st.st_ino)
+                retfacts["unique"] = f"{st.st_dev:x}g{st.st_ino:x}"
 
             # facts can be in any order but we sort them by name
-            factstring = "".join(["%s=%s;" % (x, retfacts[x])
-                                  for x in sorted(retfacts.keys())])
-            line = "%s %s\r\n" % (factstring, basename)
-            yield line.encode('utf8', self.cmd_channel.unicode_errors)
+            factstring = "".join(
+                [f"{x}={retfacts[x]};" for x in sorted(retfacts.keys())]
+            )
+            line = f"{factstring} {basename}\r\n"
+            yield line.encode(
+                self.cmd_channel.encoding, self.cmd_channel.unicode_errors
+            )
 
 
 # ===================================================================
 # --- platform specific implementation
 # ===================================================================
 
-if os.name == 'posix':
-    __all__.append('UnixFilesystem')
+if os.name == "posix":
+    __all__ += ["UnixFilesystem"]
 
     class UnixFilesystem(AbstractedFS):
         """Represents the real UNIX filesystem.
